# Responses from SDK


<!-- List Available Brokers -->
::: quantsapp._execution._modules._broker_list_models.Response_ListAvailableBrokers
    options:
        show_root_heading: true
        show_root_full_path: false

::: quantsapp._execution._modules._broker_list_models.ResponseListAvailableBrokers_Type
    options:
        show_root_heading: true
        show_root_full_path: false

---

<!-- List Mapped Brokers -->
::: quantsapp._execution._modules._broker_list_models.Response_ListMappedBrokers
    options:
        show_root_heading: true
        show_root_full_path: false

---

<!-- Add broker -->
::: quantsapp._execution._modules._broker_add_models.Response_AddBroker
    options:
        show_root_heading: true
        show_root_full_path: false

::: quantsapp._execution._modules._broker_add_models.PayloadDhanBrokerLoginCredentials_Type
    options:
        show_root_heading: true
        show_root_full_path: false

::: quantsapp._execution._modules._broker_add_models.PayloadChoiceBrokerLoginCredentials_Type
    options:
        show_root_heading: true
        show_root_full_path: false


---

<!-- Delete Broker -->


::: quantsapp._execution._modules._broker_delete_models.Response_DeleteBroker
    options:
        show_root_heading: true
        show_root_full_path: false


---

<!-- Get OrderBook -->

::: quantsapp._execution._modules._order_list_models.PayloadListOrdersFilters_Type
    options:
        show_root_heading: true
        show_root_full_path: false

::: quantsapp._execution._modules._order_list_models.Response_ListOrders
    options:
        show_root_heading: true
        show_root_full_path: false

---

<!-- Place Order -->

::: quantsapp._execution._modules._order_place_models.PayloadPlaceOrderBrokerAccounts_Type
    options:
        show_root_heading: true
        show_root_full_path: false


::: quantsapp._execution._modules._order_place_models.PayloadPlaceOrderLeg_Type
    options:
        show_root_heading: true
        show_root_full_path: false


::: quantsapp._execution._modules._order_place_models.Response_PlaceOrder
    options:
        show_root_heading: true
        show_root_full_path: false


---

<!-- Modify Order -->

::: quantsapp._execution._modules._order_modify_models.Response_ModifyOrder
    options:
        show_root_heading: true
        show_root_full_path: false

---

<!-- Cancel Orders -->

::: quantsapp._execution._modules._order_cancel_models.PayloadCancelOrder_Type
    options:
        show_root_heading: true
        show_root_full_path: false

::: quantsapp._execution._modules._order_cancel_models.Response_CancelOrders
    options:
        show_root_heading: true
        show_root_full_path: false

::: quantsapp._execution._modules._order_cancel_models.Response_CancelAllOrders
    options:
        show_root_heading: true
        show_root_full_path: false

---

<!-- Get Positions -->

::: quantsapp._execution._modules._position_list_models.PayloadGetPositions_Type
    options:
        show_root_heading: true
        show_root_full_path: false

::: quantsapp._execution._modules._position_list_models.Response_GetPositions
    options:
        show_root_heading: true
        show_root_full_path: false

::: quantsapp._execution._modules._position_list_models.Response_GetPositionsCombined
    options:
        show_root_heading: true
        show_root_full_path: false

---

<!-- Get Order Log -->

::: quantsapp._execution._modules._order_logs_models.Response_GetOrderLogs
    options:
        show_root_heading: true
        show_root_full_path: false

---

<!-- Broker Websocket -->

::: quantsapp._execution._modules._broker_ws_conn_models.Response_GetBrokerWebsocketConnectionStatus
    options:
        show_root_heading: true
        show_root_full_path: false

::: quantsapp._execution._modules._broker_ws_conn_models.Response_BrokerWebsocketReConnect
    options:
        show_root_heading: true
        show_root_full_path: false